Creates a console appender for sandbox logging with a specified layout.

.createConsoleAppenderForSandboxLogging(
  layout = ParallelLogger::layoutParallel,
  sToken
)

Arguments

layout

A layout function for the logger. Defaults to ParallelLogger::layoutParallel.

sToken

The session token to be added to log entries

Value

An appender object for logging.