Retrieves the CDM source information from the vocabulary schema of an OMOP CDM database. Retrieves the API information from the vocabulary schema of an OMOP CDM database. This includes metadata about the API, version, and other administrative details.

getAPIInfo(CDMdbHandler)

Arguments

CDMdbHandler

A CDMdbHandler object that contains database connection details

Value

A tibble containing the CDM source information with columns from the cdm_source table