A memoised version of the getConceptsWithCodeCounts function that caches results to improve performance for repeated calls with the same parameters. The CDMdbHandler argument is omitted from the cache key to allow sharing across different database connections.

getConceptsWithCodeCounts_memoise(
  CDMdbHandler,
  codeCountsTable = "code_counts"
)

Arguments

CDMdbHandler

A CDMdbHandler object that contains database connection details

codeCountsTable

Name of the code counts table in the results schema. Defaults to "code_counts"

Value

A tibble with columns:

  • concept_id - The OMOP concept ID

  • concept_name - The human-readable concept name

  • concept_code - The concept code

  • domain_id - The domain identifier (e.g., Condition, Procedure, Drug, etc.)

  • vocabulary_id - The vocabulary identifier (e.g., SNOMED, ICD10)

  • standard_concept - Logical indicating if this is a standard concept