Downloads and extracts the FinnGen Eunomia database if it doesn't exist locally. Copies the database to a temporary directory and returns the path.

helper_FinnGen_getDatabaseFile(df = "R13")

Arguments

df

Character string specifying the FinnGen dataset version. Defaults to "R13".

Value

Path to the FinnGen Eunomia SQLite database file (temporary copy)

Note

This function requires the EUNOMIA_DATA_FOLDER environment variable to be set to the path of the Eunomia data folder.

Examples

if (FALSE) { # \dontrun{
# Get basic database file
db_path <- helper_FinnGen_getDatabaseFile()

# Get database file with counts table
db_path_with_counts <- helper_FinnGen_getDatabaseFile(counts = TRUE)
} # }