R/HadesExtras.R
HadesExtras_readAndParseYaml.RdReads a YAML file from a given path, replaces specified placeholders with provided values, and returns the parsed content. If any provided placeholders are not found in the YAML file, the function throws an error.
HadesExtras_readAndParseYaml(pathToYalmFile, ...)A parsed list representing the contents of the modified YAML file.